"""T-01: Package structure validation tests."""


def test_horn_package_importable():
    import horn
    assert horn is not None


def test_horn_has_version():
    import horn
    assert hasattr(horn, "__version__")
    assert isinstance(horn.__version__, str)
    assert len(horn.__version__) > 0


def test_horn_tts_subpackage_importable():
    import horn.tts
    assert horn.tts is not None
