"""T-05: Cursor Rules template content tests."""
import importlib.resources as resources


def _load_horn_mdc() -> str:
    return resources.files("horn.rules").joinpath("horn.mdc").read_text(encoding="utf-8")


def test_horn_mdc_is_accessible():
    content = _load_horn_mdc()
    assert len(content) > 0


def test_horn_mdc_contains_start_trigger():
    content = _load_horn_mdc()
    assert "horn --start" in content


def test_horn_mdc_contains_done_trigger():
    content = _load_horn_mdc()
    assert "horn --done" in content


def test_horn_mdc_contains_confirm_trigger():
    content = _load_horn_mdc()
    assert "horn --confirm" in content
